@@ -1,5 +1,6 @@
 import copy
 import mock
+import urllib
 
 import rollbar
 
@@ -8,20 +9,28 @@ from . import BaseTest
 try:
     # Python 3
     import urllib.parse as urlparse
+    urllibquote = urlparse.quote
 except ImportError:
     # Python 2
     import urlparse
+    import urllib
+    urllibquote = urllib.quote
 
 _test_access_token = 'aaaabbbbccccddddeeeeffff00001111'
 _default_settings = copy.deepcopy(rollbar.SETTINGS)
 
+SNOWMAN = '\xe2\x98\x83'
 
 class RollbarTest(BaseTest):
     def setUp(self):
         rollbar._initialized = False
         rollbar.SETTINGS = copy.deepcopy(_default_settings)
-        rollbar.SETTINGS['locals']['enabled'] = True
-        rollbar.init(_test_access_token)
+        rollbar.init(_test_access_token, locals={'enabled': True}, dummy_key='asdf', timeout=12345)
+
+    def test_merged_settings(self):
+        self.assertDictEqual(rollbar.SETTINGS['locals'], {'enabled': True, 'sizes': rollbar.DEFAULT_LOCALS_SIZES})
+        self.assertEqual(rollbar.SETTINGS['timeout'], 12345)
+        self.assertEqual(rollbar.SETTINGS['dummy_key'], 'asdf')
 
     def test_default_configuration(self):
         self.assertEqual(rollbar.SETTINGS['access_token'], _test_access_token)
@@ -177,7 +186,8 @@ class RollbarTest(BaseTest):
                 }
             },
             'password_confirmation': None,
-            'confirm_password': 341254213
+            'confirm_password': 341254213,
+            333: 444
         }
 
         scrubbed = rollbar._scrub_obj(params, replacement_character='-')
@@ -194,7 +204,8 @@ class RollbarTest(BaseTest):
             'passwd': [{'-': '-'}, {'-': '-'}],
             'secret': {'-': '-'},
             'password_confirmation': '-',
-            'confirm_password': '-'
+            'confirm_password': '-',
+            333: 444
         })
 
     def test_non_dict_scrubbing(self):
@@ -226,6 +237,69 @@ class RollbarTest(BaseTest):
             'secret': ['------']
         })
 
+    def test_utf8_url_val_scrubbing(self):
+        url = 'http://foo.com/?password=password&foo=bar&secret=%s' % SNOWMAN
+
+        scrubbed_url = urlparse.urlparse(rollbar._scrub_request_url(url))
+        qs_params = urlparse.parse_qs(scrubbed_url.query)
+
+        self.assertDictEqual(qs_params, {
+            'password': ['--------'],
+            'foo': ['bar'],
+            'secret': [''.join(['-'] * len(SNOWMAN))]
+        })
+
+
+    def test_utf8_url_key_scrubbing(self):
+        url = 'http://foo.com/?password=password&foo=bar&%s=secret' % urllibquote(SNOWMAN)
+
+        rollbar.SETTINGS['scrub_fields'].append(SNOWMAN)
+        scrubbed_url = rollbar._scrub_request_url(url)
+
+        qs_params = urlparse.parse_qs(urlparse.urlparse(scrubbed_url).query)
+
+        self.assertEqual(['------'], qs_params[SNOWMAN])
+        self.assertEqual(['--------'], qs_params['password'])
+        self.assertEqual(['bar'], qs_params['foo'])
+
+
+    def test_unicode_val_scrubbing(self):
+        s = '%s is a unicode snowman!' % SNOWMAN
+        obj = {
+            'password': s
+        }
+
+        scrubbed = rollbar._scrub_obj(obj)
+
+        self.assertDictEqual(scrubbed, {
+            'password': ''.join(['*'] * len(s))
+        })
+
+    def test_unicode_key_scrubbing(self):
+        s = 'is a unicode snowman!'
+        obj = {
+            SNOWMAN: s
+        }
+
+        rollbar.SETTINGS['scrub_fields'].append(SNOWMAN)
+        scrubbed = rollbar._scrub_obj(obj)
+
+        self.assertDictEqual(scrubbed, {
+            SNOWMAN: ''.join(['*'] * len(s))
+        })
+
+        obj2 = {
+            SNOWMAN: s
+        }
+
+        rollbar.SETTINGS['scrub_fields'].pop()
+        rollbar.SETTINGS['scrub_fields'].append(SNOWMAN)
+        scrubbed = rollbar._scrub_obj(obj2)
+
+        self.assertDictEqual(scrubbed, {
+            SNOWMAN: ''.join(['*'] * len(s))
+        })
+
     @mock.patch('rollbar.send_payload')
     def test_uuid(self, send_payload):
         uuid = rollbar.report_message('foo')
@@ -562,7 +636,7 @@ class RollbarTest(BaseTest):
     def test_all_project_frames_have_locals(self, send_payload):
 
         prev_root = rollbar.SETTINGS['root']
-        rollbar.SETTINGS['root'] = __file__
+        rollbar.SETTINGS['root'] = __file__.rstrip('pyc')
         try:
             step1()
         except:
@@ -606,7 +680,7 @@ class RollbarTest(BaseTest):
     def test_modify_arg(self, send_payload):
         # Record locals for all frames
         prev_root = rollbar.SETTINGS['root']
-        rollbar.SETTINGS['root'] = __file__
+        rollbar.SETTINGS['root'] = __file__.rstrip('pyc')
         try:
             called_with('original value')
         except:
